pub enum EditError {
StateEvent,
NotAuthor,
Fetch(Box<Error>),
Deserialize(Error),
IncompatibleEditType {
target: String,
new_content: &'static str,
},
}Expand description
An error occurring while editing an event.
Variants
StateEvent
We tried to edit a state event, which is not allowed, per spec.
NotAuthor
We tried to edit an event which sender isn’t the current user, which is forbidden, per spec.
Fetch(Box<Error>)
We couldn’t fetch the remote event with /room/event.
Deserialize(Error)
We couldn’t properly deserialize the target event.
IncompatibleEditType
We tried to edit an event of type A with content of type B.